@@ -19,8 +19,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef SYSTEM_ANALYZER_H
-#define SYSTEM_ANALYZER_H
+#pragma once
 
 #include "syslogAnalyzer.h"
 
@@ -38,4 +37,3 @@ public:
     }
 };
 
-#endif
